@@ -27,7 +27,9 @@ w4 = gui.HSlider(min_value=20, length=10, x=200, y=160)
 w9 = gui.VSlider(length=40, x=600, y=160, step=False)
 l1 = gui.Label(value="Pulsate:", x=395, y=30, font_size=25)
 
-data = "This example is to demonstrate GooeyPy's widgets and functionality."
+data = """This example is to demonstrate GooeyPy's widgets and functionality.
+
+You can also have line breaks."""
 tb = gui.TextBlock(value=data, x=200, y=350, width=300)
 
 # Add our widgets to our App.
@@ -76,8 +78,6 @@ sb1.add(w2, "inputvalue")
 # Ok, now we add it to the App...
 app.add(sb1)
 
-
-
 # Connections are still useful, lets make one. Here is our callback.
 def callback():
     # Basically, if w3 (which is a switch) is on, we make w2 (an input widget)
