@@ -82,9 +82,14 @@ class App(Container):
 
 
     def get_image(self, path, colorkey=-1, nocache=False):
-        path = os.path.join(self.path, path)
+        if os.path.isfile(os.path.join(self.path, path)):
+            path = os.path.join(self.path, path) 
         return util.get_image(path, colorkey=-1, nocache=False)
 
+    #def get_image(self, path, colorkey=-1, nocache=False):
+        #path = os.path.join(self.path, path)
+        #return util.get_image(path, colorkey=-1, nocache=False)
+
     def load_theme(self, theme_name):
         paths = []
         paths.append(os.path.join("data", "themes", theme_name))
