@@ -24,13 +24,14 @@ class Image(widget.Widget):
         util.blit(self.value, self.pos, clip_rect=self.value.get_rect())
 
 
-    @ComputedCellDescriptor
     def height(self):
         h = self.value.get_height() + self.style_option["padding-bottom"]+\
                 self.style_option["padding-top"]
         return widget.Widget.height.function(self, h)
-    @ComputedCellDescriptor
+    height = ComputedCellDescriptor(height)
+
     def width(self):
         w = self.value.get_width() + self.style_option["padding-right"]+\
                 self.style_option["padding-left"]
-        return widget.Widget.width.function(self, w)
\ No newline at end of file
+        return widget.Widget.width.function(self, w)
+    width = ComputedCellDescriptor(width)
\ No newline at end of file
