@@ -33,7 +33,6 @@ class Input(widget.Widget):
         self.value = value
 
 
-    @ComputedCellDescriptor
     def font(self):
         """
         Input.font -> pygame.Font
@@ -44,6 +43,7 @@ class Input(widget.Widget):
         if self.style_option["font-weight"] == "bold":
             f.set_bold(True)
         return f
+    font = ComputedCellDescriptor(font)
 
     def set_value(self,v):
         if v == None: v = ''
@@ -57,37 +57,38 @@ class Input(widget.Widget):
         self.send(CHANGE)
     value = property(lambda self: self._value, set_value)
 
-    @ComputedCellDescriptor
     def size(self):
         s,_ = self.font.size("e")
         num = self.style_option["width"]/s
         return self.font.size("e"*num)
+    size = ComputedCellDescriptor(size)
 
-    @ComputedCellDescriptor
     def width(self):
         w = self.size[0] + self.style_option["padding-left"]+\
                 self.style_option["padding-right"]
         return widget.Widget.width.function(self, w)
+    width = ComputedCellDescriptor(width)
 
-    @ComputedCellDescriptor
     def height(self):
         h = self.size[1] + self.style_option["padding-top"]+\
                 self.style_option["padding-bottom"]
         return widget.Widget.height.function(self, h)
+    height = ComputedCellDescriptor(height)
 
-    @ComputedCellDescriptor
     def font_clip_rect(self):
         vx = max(self.font.size(self.value)[0] - self.size[0], 0)
         return pygame.Rect((vx, 0), self.size)
+    font_clip_rect = ComputedCellDescriptor(font_clip_rect)
 
-    @ComputedCellDescriptor
     def font_x(self):
         x,_ = self.pos
         return x + self.style_option["padding-left"]
-    @ComputedCellDescriptor
+    font_x = ComputedCellDescriptor(font_x)
+
     def font_y(self):
         _,y = self.pos
         return y + self.style_option["padding-top"]
+    font_y = ComputedCellDescriptor(font_y)
 
     def draw_widget(self):
         util.blit(self.font.render(self.value, self.style_option["antialias"],
