@@ -22,7 +22,6 @@ class Label(widget.Widget):
 
         self.value = value
 
-    @ComputedCellDescriptor
     def font(self):
         """
         Label.font -> pygame.Font
@@ -33,40 +32,43 @@ class Label(widget.Widget):
         if self.style_option["font-weight"] == "bold":
             f.set_bold(True)
         return f
+    font = ComputedCellDescriptor(font)
 
-    @ComputedCellDescriptor
     def width(self):
         w = self.font.size(self.value)[0]+self.style_option["padding-left"]+\
                 self.style_option["padding-right"]
         return widget.Widget.width.function(self, w)
+    width = ComputedCellDescriptor(width)
 
-    @ComputedCellDescriptor
     def height(self):
         h = self.font.size(self.value)[1]+self.style_option["padding-top"]+\
                 self.style_option["padding-bottom"]
         return widget.Widget.height.function(self, h)
+    height = ComputedCellDescriptor(height)
 
-    @ComputedCellDescriptor
     def font_x(self):
         x,_ = self.pos
         return x + self.style_option["padding-left"]
-    @ComputedCellDescriptor
+    font_x = ComputedCellDescriptor(font_x)
+
     def font_y(self):
         _,y = self.pos
         return y + self.style_option["padding-top"]
+    font_y = ComputedCellDescriptor(font_y)
 
-    @ComputedCellDescriptor
     def clip_rect(self):
         return pygame.Rect(0,0,
                 self.width-(self.style_option["padding-left"]+\
                 self.style_option["padding-right"]),
                 self.height-(self.style_option["padding-top"]+\
                 self.style_option["padding-bottom"]))
+    clip_rect = ComputedCellDescriptor(clip_rect)
+
 
-    @ComputedCellDescriptor
     def font_value(self):
         return self.font.render(self.value, self.style_option["antialias"],
                 self.style_option["color"])
+    font_value = ComputedCellDescriptor(font_value)
 
     def draw_widget(self):
         # We do this incase we are trying to blit the text into a space smaller
