@@ -53,8 +53,18 @@ class StyleSet(object):
     spacing          12 # For certain container widgets.
     opacity          25 # Alpha value. Valid otpions between 0 and 255.
     antialias        1 | 0
+    align            left | right | center
+    valign           top | bottom | center
     ===============  =======================================================
 
+    Something to note about align and valign. When they are changed from their
+    default values (top and left), the x and y values act as an offset. So if
+    you are aligning a widget center and have an x value of 100, the widget will
+    display 100 pixels to the right of the center of it's parent (or container)
+    widget.
+
+    Also, aligning only takes effect when positioning is relative (which is
+    default).
 
 
     Arguments
@@ -69,6 +79,9 @@ class StyleSet(object):
     parent = util.ReplaceableCellDescriptor()
     widget = util.ReplaceableCellDescriptor()
 
+    # Setting a default style option here will make it use it at all times
+    # unless explicitly set. In other words, inheriting doesn't work for these
+    # options.
     default_styles = {
         "padding-top":0,
         "padding-right":0,
@@ -84,6 +97,8 @@ class StyleSet(object):
         "x":0,
         "y":0,
         "position":"relative",
+        #"align":"left",
+        #"valign":"top",
         }
 
     def __init__(self, widget, parent=None):
@@ -100,7 +115,6 @@ class StyleSet(object):
     applied_styles = property(lambda self: self._applied_styles)
 
 
-    @ComputedCellDescriptor
     def surf(self):
         """
         StyleSet.surf -> pygame.Surface
@@ -119,6 +133,7 @@ class StyleSet(object):
         for (option, values) in self.applied_styles.items():
             s = self.apply(s, option, values)
         return s
+    surf = ComputedCellDescriptor(surf)
 
 
     def __getitem__(self, v):
@@ -175,6 +190,8 @@ class StyleSet(object):
             if len(v) == 1:
                 v = v[0]
                 v = str(v)
+                # For some reason isdigit returns False if v is something like
+                # '-20'. FIX?
                 if v.isdigit(): v = int(v)
         self.applied_styles[n] = v
         return surf
