@@ -93,9 +93,16 @@ class Widget(DependantCell):
 
         self.hovering = False
         self.focused = False
-        self.parent = parent
         self.active = active
+
+        # There is a subtle difference between parent and container. A widget
+        # can have any other widget as a parent while a container must be a
+        # Container widget. parent is used for inheriting styles and positioning
+        # with padding and aligning. Normally, when a widget has a container,
+        # it's parent is the same as it.
+        self.parent = parent
         self.container = None
+
         self.connects = {}
 
         # Move to widgets that use it?
@@ -249,35 +256,51 @@ class Widget(DependantCell):
 
     def set_x(self,v):
         self.stylesets["default"]["x"] = v
-    x = property(lambda self:self.stylesets["default"]["x"], set_x)
+    x = property(lambda self:int(self.stylesets["default"]["x"]), set_x)
     def set_y(self,v):
         self.stylesets["default"]["y"] = v
-    y = property(lambda self:self.stylesets["default"]["y"], set_y)
+    y = property(lambda self:int(self.stylesets["default"]["y"]), set_y)
 
-
-    @ComputedCellDescriptor
     def pos(self, pos=None):
         """
         Widget.pos -> Tuple
         ^^^^^^^^^^^^^^^^^^^
-        Get the actual position """
+        Get the actual position that the widget should be drawn to and receive
+        events at. """
         if pos:
             x,y = pos
         else:
-            x = self.style_option["x"]
-            y = self.style_option["y"]
+            x = int(self.style_option["x"])
+            y = int(self.style_option["y"])
         if self.style_option["position"] == "relative":
             if self.parent:
                 px, py = self.parent.pos
-                x += px + self.parent.stylesets["default"]["padding-left"]
-                y += py + self.parent.stylesets["default"]["padding-top"]
+
+                # Padding.
+                x += px #+ int(self.parent.stylesets["default"]["padding-left"])
+                y += py #+ int(self.parent.stylesets["default"]["padding-top"])
+
+                # Alignment positioning.
+                if self.style_option["align"] == "center":
+                    x += (self.parent.width - self.width) / 2
+                elif self.style_option["align"] == "right":
+                    x += (self.parent.width - self.width)
+                else:
+                    x += int(self.parent.stylesets["default"]["padding-left"])
+
+                if self.style_option["valign"] == "center":
+                    y += (self.parent.height - self.height) / 2
+                elif self.style_option["valign"] == "bottom":
+                    y += (self.parent.height - self.height)
+                else:
+                    y += int(self.parent.stylesets["default"]["padding-top"])
             if self.container:
                 x -= self.container.offset_x
                 y -= self.container.offset_y
         return (x,y)
+    pos = ComputedCellDescriptor(pos)
 
 
-    @ComputedCellDescriptor
     def width(self, w=None):
         """
         Widget.width -> int
@@ -297,8 +320,9 @@ class Widget(DependantCell):
         if max_width and width > max_width:
             w = max_width
         return w
+    width = ComputedCellDescriptor(width)
+
 
-    @ComputedCellDescriptor
     def height(self, h=None):
         """
         Widget.height -> int
@@ -318,9 +342,9 @@ class Widget(DependantCell):
         if max_height and height > max_height:
             h = max_height
         return h
+    height = ComputedCellDescriptor(height)
 
 
-    @ComputedCellDescriptor
     def rect(self):
         """
         Widget.rect -> pygame.Rect
@@ -330,12 +354,12 @@ class Widget(DependantCell):
         r = self.surface.get_rect()
         r.x, r.y = self.pos
         return r
+    rect = ComputedCellDescriptor(rect)
 
-    @ComputedCellDescriptor
     def focusable(self):
         return self.style_option["focusable"]
+    focusable = ComputedCellDescriptor(focusable)
 
-    @ComputedCellDescriptor
     def style(self):
         """
         Widget.style -> StyleSet
@@ -354,10 +378,11 @@ class Widget(DependantCell):
             return self.stylesets["focused"]
         else:
             return self.stylesets["default"]
+    style = ComputedCellDescriptor(style)
 
-    @ComputedCellDescriptor
     def surface(self):
         return self.style.surf
+    surface = ComputedCellDescriptor(surface)
 
 
     def draw(self):
@@ -402,10 +427,12 @@ class Widget(DependantCell):
                             clip_rect=self._last_blit_rect)
 
                 #clip_rect = surf.get_rect()
-                #if self.container:
+                #if self.container and self.style_option["position"] == "relative":
                     #clip_rect = self.container.rect
-                    #clip_rect.x = min(self.x-self.container.offset_x, self.x)
-                    #clip_rect.y = min(self.y-self.container.offset_y, self.y)
+                    #clip_rect.x = self.container.offset_x
+                    #clip_rect.y = min(self.container.offset_y, self.y)
+                    #x += clip_rect.x
+                    #y += clip_rect.y
 
                 self._last_blit_rect = util.blit(surf, (x, y))
                 self.draw_widget()
@@ -421,26 +448,6 @@ class Widget(DependantCell):
         """
         pass
 
-    #def focus(self):
-        #"""
-        #Widget.focus() -> None
-        #^^^^^^^^^^^^^^^^^^^^^^
-        #Focuses the widget
-        #"""
-        ##if getattr(self,'container',None) != None:
-            ##if self.container.myfocus != self:
-                ##self.container.focus(self)
-        #self.focused = True
-    #def blur(self):
-        #"""
-        #Widget.blur() -> None
-        #^^^^^^^^^^^^^^^^^^^^^
-        #Blurs the widget
-        #"""
-        ##if getattr(self,'container',None) != None:
-            ##self.container.blur(self)
-        #self.focused = False
-
 
     def event(self, e):
         pass
@@ -462,7 +469,7 @@ class Widget(DependantCell):
     def exit(self):
         self.hovering = False
 
-    
+
     def send(self,code,event=None):
         """
         Widget.send(code, [event]) -> None
@@ -472,14 +479,14 @@ class Widget(DependantCell):
         """
         if code in self.connects:
             con = self.connects[code]
-        
+
             fnc = con['fnc']
             values = list(con['values'])
-            
+
             nargs = fnc.func_code.co_argcount
             names = list(fnc.func_code.co_varnames)[:nargs]
             if hasattr(fnc,'im_class'): names.pop(0)
-            
+
             args = []
             magic = {'_event':event,'_code':code,'_widget':self}
             for name in names:
@@ -491,7 +498,7 @@ class Widget(DependantCell):
                     break
             args.extend(values)
             fnc(*args)
-    
+
     def _event(self,e):
         #return
         if self.disabled: return
